@@ -20,12 +20,12 @@ class Token(models.Model):
 
     category = models.CharField(max_length=255, primary_key=True, unique=True)
     name = models.CharField(max_length=255)
-    description = models.CharField(max_length=255, blank=True, default='')
+    description = models.TextField(blank=True, default='')
     symbol = models.CharField(max_length=100)
     decimals = models.PositiveIntegerField(default=0)
     icon = models.ImageField(null=True, blank=True)
     is_nft = models.BooleanField(default=False)
-    nft_description = models.CharField(max_length=255, default='')
+    nft_description = models.CharField(max_length=255, blank=True, default='')
     nft_types = JSONField(default=dict)
     '''
         NFT_TYPES
@@ -68,7 +68,7 @@ class Registry(models.Model):
     patch = models.PositiveIntegerField(default=0) # incremented when an identity is modified
     name = models.CharField(max_length=255)
     description = models.CharField(max_length=255, null=True, blank=True)
-    active = models.BooleanField(default=False)
+    active = models.BooleanField(default=True)
     date_created = models.DateTimeField(default=timezone.now)
     latest_revision = models.DateTimeField(default=timezone.now)
     tokens = models.ManyToManyField(Token)
@@ -82,7 +82,7 @@ class Registry(models.Model):
 
     class Meta:
         verbose_name_plural = 'Registries'
-        ordering = ('name', )
+        ordering = ('name', '-active', )
 
     def save(self, *args, **kwargs):
         self.latest_revision = timezone.now()
