@@ -13,7 +13,6 @@ class CashTokenSerializer(serializers.ModelSerializer):
     class Meta:
         model = Token
         fields = (
-            'id',
             'category',
             'name',
             'symbol',
@@ -27,7 +26,6 @@ class CashTokenSerializer(serializers.ModelSerializer):
             'owner',
         )
         read_only_fields = (
-            'id',
             'date_created',
             'owner',
         )
@@ -41,7 +39,6 @@ class RegistryIdentitySerializer(serializers.ModelSerializer):
     class Meta:
         model = Token
         fields = (
-            'id',
             'name',
             'description',
             'time',
@@ -49,7 +46,6 @@ class RegistryIdentitySerializer(serializers.ModelSerializer):
             'status',
             'uris',
         )
-        read_only_fields = ('id', )
 
     def get_time(self, obj):
         return {
@@ -153,7 +149,6 @@ class BcmrRegistrySerializer(serializers.ModelSerializer):
 
         for token in tokens:
             t = RegistryIdentitySerializer(token).data
-            del t['id']
             identities[t['token']['category']] = [t]
 
         return identities
